package de.cnam.jemina.migration;

import de.cnam.jemina.config.SqlManager;
import de.cnam.jemina.database.server.EmbeddedHsqlServer;
import de.cnam.jemina.objects.Artikel;
import de.cnam.jemina.objects.Filiale;
import java.io.BufferedReader;
import java.io.File;
import java.io.FileReader;
import java.io.IOException;
import java.net.URISyntaxException;
import java.sql.PreparedStatement;
import java.sql.SQLException;
import java.util.List;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

/**
 * Diese Klasse schreibt die Testdaten in die Datenbank
 * @author CNAM Team (Nadine, Mike, Jens)
 */
public class TestdataImporter {
    
    // Logging:
    private static final Logger log = LoggerFactory.getLogger(TestdataImporter.class);
    
    // DB Starten
    EmbeddedHsqlServer server; 
    
    
    public void importData() {
        try {
            // Datenbank starten:
            server = EmbeddedHsqlServer.getInstance(); 
            
            // Buecher importieren
            File buchListe = new File(TestdataImporter.class.getClassLoader().getResource("buecher.csv").toURI());
            CsvReader.insertBooks(buchListe, server.getConnection());
            
            // Testdaten importieren
            File testDaten = new File(TestdataImporter.class.getClassLoader().getResource("testDaten.sql").toURI());
            BufferedReader in = new BufferedReader(new FileReader(testDaten));
            String zeile = null;
            int counter = 0;
            while ((zeile = in.readLine()) != null) {
                if (!StringUtils.isEmpty(zeile)) {
                    try {
                        server.getConnection().executeSql(zeile);
                        counter++;
                    } catch (Exception ex) {
                        log.error("Fehler beim ausfuehren von: {}    Ursache: {}", zeile, ex.getLocalizedMessage());
                    }
                }
            }
            
            // Log
            if (log.isInfoEnabled()) {
                log.info("Es wurden {} Zeilen ausgefuehrt.", counter);
            }
            
            // Lege Exemplare an
            List<Artikel> list = server.getConnection().selectArticle(StringUtils.EMPTY);
            SqlManager sql = SqlManager.getInstance();
            
            PreparedStatement pre = server.getConnection().getConnection().prepareStatement(sql.getSql("exemplar_insert"));
            Filiale filiale = server.getConnection().getFilialeByName("Bibliothek h-da"); // @todo: Fest hinterlegt
            int fNr = 0;
            
            if (filiale != null) {
                fNr = filiale.getBesitzerId();
            }
            
            for (Artikel a : list) {
                // Lege eine bestimmte Anzahl an Exemplaren an:
                for (int i=5;i>0;i--) {
                    pre.setInt(1, a.getId());
                    pre.setBoolean(2, i<=2 ? true : false); // Es soll ein paar Bestands-Exemplare geben
                    pre.setInt(3, fNr);
                    pre.execute();
                }
            }
            
            server.getConnection().getConnection().commit();

            // Datenbank stoppen:
            server.stopDatabase();
        } catch (URISyntaxException | IOException | SQLException ex) {
            log.error("Es gabe einen Fehler beim Import der Testdaten", ex);
        }
    }
    
    
    public static void main(String[] args) {
        TestdataImporter test = new TestdataImporter();
        test.importData();
    }

}
