package de.cnam.jemina.ui.controlls.impl;

import com.vaadin.ui.Component;
import com.vaadin.ui.LoginForm;
import com.vaadin.ui.LoginForm.LoginEvent;
import de.cnam.jemina.entrypoint.IJeminaApplication;
import de.cnam.jemina.extern.auth.IUser;
import de.cnam.jemina.extern.auth.IUserDirectory;
import de.cnam.jemina.i18n.LocalizationManager;
import de.cnam.jemina.ui.controlls.IControll;
import de.cnam.jemina.ui.views.impl.LoginView;
import java.util.Map;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

/**
 * Modul "Login"
 * @author CNAM Team (Nadine, Mike, Jens)
 * @since 22.01.2013
 */
public class LoginControll implements IControll {
    
    public static final String MODUL_NAME = "Login";
    public static final String MODUL_ICON = "Login";
    
    // Fuer die Uebersetzung:
    private final LocalizationManager locale = LocalizationManager.getLocalizationManager(LoginControll.class);
    
    // Logging:
    private final Logger log = LoggerFactory.getLogger(LoginControll.class);
    
    // View (UI)
    private LoginView view;
    
    // Applikation:
    private final IJeminaApplication app;
    
    // User Directory:
    private final IUserDirectory ud;

    /**
     * 
     * @param app
     * @param ud 
     */
    public LoginControll(IJeminaApplication app, IUserDirectory ud) {
        this.app = app;
        this.ud = ud;
    }
    
    
    @Override
    public String getName() {
        return MODUL_NAME;
    }

    @Override
    public String getIconName() {
        return MODUL_ICON;
    }

    @Override
    public String getCaption() {
        return locale.localize(MODUL_NAME);
    }

    @Override
    public Component open(Object obj, Map additionalParameters) {
        view = new LoginView();
        view.addLoginListener(new LoginListener());
        
        return view;
    }
    
    /**
     * &Uuml;berpr&uuml;ft ob die angegeben Logindaten korrekt sind.
     * Ist dies der Fall wird die {@link IJeminaApplication Anwendung} dar&uuml;ber informiert.
     */
    private class LoginListener implements LoginForm.LoginListener {
        @Override
        public void onLogin(LoginEvent event) {
            final String uname = event.getLoginParameter("username");
            final String pwd = event.getLoginParameter("password");
            
            if (log.isDebugEnabled()) {
                log.debug("Loginversuch: {}", uname);
            }
            
            // Ueberpruefe Logindaten:
            IUser user = ud.checkLogin(uname, pwd);
            
            if (user != null) {
                // Login erfolgreich!
                if (log.isInfoEnabled()) {
                    log.info("Login von '{}' erfolgreich.", user.getLoginId());
                }
                
                // Der Anwendung den erfolreichen Login mitteilen:
                app.notifyLogin(user);
            } else {
                // Login NICHT erfolgreich!
                if (log.isInfoEnabled()) {
                    log.info("Login von '{}' NICHT erfolgreich!", uname);
                }
                
                // Zeige dem Anwender, dass es nicht funktioniert hat:
                app.showError(locale.localize("loginerror"));
            }
        }        
    }

}
